============================
Sealan Cloud SDK for Python
============================

Sealan Cloud Python SDK is the official software development kit, which allows Python developers to write software that makes use of Sealan Cloud services like Device Manager and SIM Card Manager

The SDK works on Python versions:

   * 3.6 and greater

Quick Start
-----------
First, install the library:

.. code-block:: sh

    $ pip install sealan-sdk 

or download source code from github and install:

.. code-block:: sh

    $ git clone https://github.com/sealan/sealan-cloud-sdk-python.git
    $ cd sealan-cloud-sdk-python
    $ python setup.py install
